{% if render_report %}
<tr class="inline-report">
     <td colspan="{{ inline_column_span }}">
        <strong>{{ report.get_title }}</strong>
    </td>
</tr>
<tr class="inline-report">
    <td colspan="{{ inline_column_span }}">
        {% include "model_report/includes/report_table.html" %}
    </td>
</tr>
{% endif %}

