{% load i18n %}
{% if form_groupby %}
    {% with form_groupby as form %}
        <fieldset>
            <legend>{% trans "Group by" %}</legend>
            {% include "model_report/includes/form_fields.html" %}
        </fieldset>
    {% endwith %}
{% endif %}
