{% load i18n %}dateFormat: "yy-mm-dd",
monthNamesShort: ['{% trans "Jan" %}','{% trans "Feb" %}','{% trans "Mar" %}','{% trans "Apr" %}','{% trans "May" %}','{% trans "Jun" %}','{% trans "Jul" %}','{% trans "Aug" %}','{% trans "Sep" %}','{% trans "Oct" %}','{% trans "Nov" %}','{% trans "Dec" %}'],
dayNamesMin: ['{% trans "Sun" %}','{% trans "Mon" %}','{% trans "Tue" %}','{% trans "Wed" %}','{% trans "Thu" %}','{% trans "Fri" %}','{% trans "Sat" %}'],
changeMonth: true,
changeYear: true
