{% load i18n %}
{% if form_filter %}
    {% with form_filter as form %}
        <fieldset>
            {% if not form.filter_report_is_all %}
            <legend>{% trans "Filter results" %}</legend>
            {% endif %}
            {% include "model_report/includes/form_fields.html" %}
        </fieldset>
    {% endwith %}
{% endif %}
